@@ -1,3 +1,20 @@
+### Checks that all arguments are TRUE or FALSE
+check.flags <- function(...) {
+    flag.bad <- vapply(list(...),
+                       function(x) { !(identical(x, TRUE) ||
+                                       identical(x, FALSE)) },
+                       TRUE,
+                       USE.NAMES = FALSE)
+    if (any(flag.bad)) {
+        offending <- vapply(match.call(expand.dots=TRUE)[c(FALSE, flag.bad)],
+                            deparse, "")
+        stop(gettextf("must be TRUE or FALSE: %s",
+                      paste(sQuote(offending), collapse=", "),
+                      domain="R-dplR"),
+             domain = NA)
+    }
+}
+
 ### Function to check if x is equivalent to its integer
 ### representation. Note: Returns FALSE for values that fall outside
 ### the range of the integer type. The result has the same shape as x;
@@ -21,20 +38,21 @@ dplr.year <- function(year, suffix) {
 ### Prints the contents of a matrix row together with column labels.
 ### By default, doesn't print NA values.  If show.all.na is TRUE,
 ### reports all-NA rows as one NA.
-row.print <- function(x, drop.na=TRUE, show.all.na=TRUE, collapse=", "){
-    if(drop.na){
+row.print <- function(x, drop.na=TRUE, show.all.na=TRUE, collapse=", ") {
+    if (drop.na) {
         not.na <- !is.na(x)
-        if(any(not.na))
+        if (any(not.na)) {
             paste(colnames(x)[not.na], x[not.na], sep=": ", collapse=collapse)
-        else if(show.all.na)
+        } else if (show.all.na) {
             as.character(NA)
-    } else{
+        }
+    } else {
         paste(colnames(x), x, sep=": ", collapse=collapse)
     }
 }
 
 ### Returns indices of rows in matrix X that match with pattern.
-row.match <- function(X, pattern){
+row.match <- function(X, pattern) {
     which(apply(X, 1,
                 function(x) {
                     all(is.na(x) == is.na(pattern)) &&
@@ -46,23 +64,25 @@ row.match <- function(X, pattern){
 ### The equivalent of the C loop 'for(i=from;i<=to;i++){}'
 ### can be achieved by writing 'for(i in inc(from,to)){}'.
 ### Note that for(i in from:to) fails to do the same if to < from.
-inc <- function(from, to){
-    if(is.numeric(to) && is.numeric(from) && to >= from)
+inc <- function(from, to) {
+    if (is.numeric(to) && is.numeric(from) && to >= from) {
         seq(from=from, to=to)
-    else
+    } else {
         integer(length=0)
+    }
 }
 
 ### Decreasing sequence. See inc.
-dec <- function(from, to){
-    if(is.numeric(to) && is.numeric(from) && to <= from)
+dec <- function(from, to) {
+    if (is.numeric(to) && is.numeric(from) && to <= from) {
         seq(from=from, to=to)
-    else
+    } else {
         integer(length=0)
+    }
 }
 
 ### AR function for chron, normalize1, normalize.xdate, ...
-ar.func <- function(x){
+ar.func <- function(x) {
     y <- x
     idx.goody <- !is.na(y)
     ar1 <- ar(y[idx.goody])
@@ -71,22 +91,22 @@ ar.func <- function(x){
 }
 
 ### Range of years. Used in cms, rcs, rwl.stats, seg.plot, spag.plot, ...
-yr.range <- function(x, yr.vec = as.numeric(names(x))){
+yr.range <- function(x, yr.vec = as.numeric(names(x))) {
     range(yr.vec[!is.na(x)])
 }
 
 ### Multiple ranges of years.
-yr.ranges <- function(x, yr.vec = as.numeric(names(x))){
+yr.ranges <- function(x, yr.vec = as.numeric(names(x))) {
     na.flag <- is.na(x)
     idx.good <- which(!na.flag)
     idx.bad <- which(na.flag)
     n <- length(x)
     res <- matrix(nrow=ceiling(n / 2), ncol=2)
     k <- 0
-    while(length(idx.good) > 0) {
+    while (length(idx.good) > 0) {
         first.good <- idx.good[1]
         idx.bad <- idx.bad[idx.bad > first.good]
-        if(length(idx.bad) > 0) {
+        if (length(idx.bad) > 0) {
             first.bad <- idx.bad[1]
         } else {
             first.bad <- n + 1
@@ -98,9 +118,9 @@ yr.ranges <- function(x, yr.vec = as.numeric(names(x))){
 }
 
 ### Used in cms, rcs, ...
-sortByIndex <- function(x){
+sortByIndex <- function(x) {
     lowerBound <- which.min(is.na(x))
-    c(x[lowerBound:length(x)], rep(NA, lowerBound-1))
+    c(x[lowerBound:length(x)], rep(NA, lowerBound - 1))
 }
 
 ### Increment the given number (vector) x by one in the given base.
@@ -108,14 +128,14 @@ sortByIndex <- function(x){
 ### the smallest digit is one. Basically, we have a shift of one because
 ### of array indices starting from 1 instead of 0.  In case another
 ### digit is needed in the front, the result vector y grows.
-count.base <- function(x, base){
+count.base <- function(x, base) {
     n.x <- length(x)
     pos <- n.x
     y <- x
     y[pos] <- y[pos] + 1
-    while (y[pos] == base + 1){
+    while (y[pos] == base + 1) {
         y[pos] <- 1
-        if (pos == 1){
+        if (pos == 1) {
             temp <- vector(mode="integer", length=n.x+1)
             temp[-1] <- y
             pos <- 2
@@ -130,17 +150,18 @@ count.base <- function(x, base){
 ### Compose a new name by attaching a suffix, which may partially
 ### replace the original name depending on the limit imposed on the
 ### length of names.
-compose.name <- function(orig.name, alphabet, idx, limit){
+compose.name <- function(orig.name, alphabet, idx, limit) {
     idx.length <- length(idx)
-    if (!is.null(limit) && idx.length > limit){
+    if (!is.null(limit) && idx.length > limit) {
         new.name <- ""
-    } else{
+    } else {
         last.part <- paste(alphabet[idx], collapse="")
-        if(is.null(limit))
-            new.name <- paste(orig.name, last.part, sep="")
-        else
-            new.name <- paste(strtrim(orig.name,limit-idx.length),
-                              last.part, sep="")
+        if (is.null(limit)) {
+            new.name <- paste0(orig.name, last.part)
+        } else {
+            new.name <- paste0(strtrim(orig.name, limit - idx.length),
+                               last.part)
+        }
     }
     new.name
 }
@@ -151,29 +172,31 @@ compose.name <- function(orig.name, alphabet, idx, limit){
 ### approach should be good enough for all but the most pathological
 ### cases. The output vector keeps the names of the input vector.
 fix.names <- function(x, limit=NULL, mapping.fname="", mapping.append=FALSE,
-                      basic.charset=TRUE){
+                      basic.charset=TRUE) {
     write.map <- FALSE
     n.x <- length(x)
     x.cut <- x
     rename.flag <- rep(FALSE, n.x)
-    if(basic.charset){
+    if (basic.charset) {
         bad.chars <- paste(c("[^",LETTERS,letters,0:9,"]"),collapse="")
         idx.bad <- grep(bad.chars, x.cut, perl=TRUE)
-        if(length(idx.bad) > 0){
+        if (length(idx.bad) > 0) {
             warning("characters outside a-z, A-Z, 0-9 present: renaming series")
-            if(nchar(mapping.fname)>0)
+            if (nchar(mapping.fname) > 0) {
                 write.map <- TRUE
+            }
             rename.flag[idx.bad] <- TRUE
             ## Remove inappropriate characters (replace with nothing)
             x.cut[idx.bad] <- gsub(bad.chars, "", x.cut[idx.bad])
         }
     }
-    if(!is.null(limit)){
+    if (!is.null(limit)) {
         over.limit <- nchar(x.cut) > limit
-        if(any(over.limit)){
+        if (any(over.limit)) {
             warning("some names are too long: renaming series")
-            if(nchar(mapping.fname)>0)
+            if (nchar(mapping.fname) > 0) {
                 write.map <- TRUE
+            }
             rename.flag[over.limit] <- TRUE
             x.cut[over.limit] <- strtrim(x.cut[over.limit], limit)
         }
@@ -183,51 +206,55 @@ fix.names <- function(x, limit=NULL, mapping.fname="", mapping.append=FALSE,
     ## Check if there are duplicate names after truncation and removal
     ## of inappropriate characters.  No duplicates => nothing to do
     ## beyond this point, except return the result.
-    if (n.unique == n.x){
+    if (n.unique == n.x) {
         y <- x.cut
     } else {
         warning("duplicate names present: renaming series")
-        if(nchar(mapping.fname)>0)
+        if (nchar(mapping.fname) > 0) {
             write.map <- TRUE
+        }
 
         y <- character(length=n.x)
         names(y) <- names(x)
         alphanumeric <- c(0:9, LETTERS, letters)
         n.an <- length(alphanumeric)
         ## First pass: Keep already unique names
-        for (i in 1:n.unique){
+        for (i in 1:n.unique) {
             idx.this <- which(x.cut %in% unique.cut[i])
             n.this <- length(idx.this)
-            if (n.this == 1)
+            if (n.this == 1) {
                 y[idx.this] <- x.cut[idx.this]
+            }
         }
 
-        if(!is.null(limit))
+        if (!is.null(limit)) {
             x.cut <- strtrim(x.cut, limit-1)
+        }
         x.cut[y != ""] <- NA
         unique.cut <- unique(x.cut) # may contain NA
         n.unique <- length(unique.cut)
         ## Second pass (exclude names that were set in the first pass):
         ## Make rest of the names unique
-        for (i in 1:n.unique){
+        for (i in 1:n.unique) {
             this.substr <- unique.cut[i]
-            if (is.na(this.substr)) # skip NA
+            if (is.na(this.substr)) {# skip NA
                 next
+            }
             idx.this <- which(x.cut %in% this.substr)
             n.this <- length(idx.this)
             suffix.count <- 0
             for (j in 1:n.this){
                 still.looking <- TRUE
-                while (still.looking){
+                while (still.looking) {
                     suffix.count <- count.base(suffix.count, n.an)
                     proposed <-
                         compose.name(unique.cut[i],alphanumeric,suffix.count,limit)
-                    if (nchar(proposed)==0){
+                    if (nchar(proposed) == 0) {
                         warning("could not remap a name: some series will be missing")
                         still.looking <- FALSE
                         ## F for Fail...
-                        proposed <- paste(unique.cut[i], "F", sep="")
-                    } else if (!any(y %in% proposed)){
+                        proposed <- paste0(unique.cut[i], "F")
+                    } else if (!any(y %in% proposed)) {
                         still.looking <- FALSE
                     }
                 }
@@ -237,14 +264,16 @@ fix.names <- function(x, limit=NULL, mapping.fname="", mapping.append=FALSE,
             }
         }
     }
-    if(write.map){
-        if(mapping.append && file.exists(mapping.fname))
+    if (write.map) {
+        if (mapping.append && file.exists(mapping.fname)) {
             map.file <- file(mapping.fname, "a")
-        else
+        } else {
             map.file <- file(mapping.fname, "w")
-        for(i in which(rename.flag)){
-            if(x[i] != y[i])
+        }
+        for (i in which(rename.flag)) {
+            if (x[i] != y[i]) {
                 cat(x[i], "\t", y[i], "\n", file=map.file, sep = "")
+            }
         }
         close(map.file)
     }
