@@ -503,12 +503,13 @@ flush(stderr()); flush(stdout())
 
 ### Name: read.ids
 ### Title: Read Site-Tree-Core IDs
-### Aliases: read.ids
+### Aliases: read.ids autoread.ids
 ### Keywords: misc
 
 ### ** Examples
 data(ca533)
 read.ids(ca533, stc = c(3, 2, 3))
+autoread.ids(ca533)
 
 
 
